'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = reduce;

var _lodash = require('lodash');

var _client = require('@slack/client');

var _channelHelpers = require('./channel-helpers');

var _utils = require('./utils');

var _messagesReducer = require('./messages-reducer');

var _messagesReducer2 = _interopRequireDefault(_messagesReducer);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * channels: {
 *    <channelId>: {
 *      messages: {
 *        <messageTs>: {},
 *        <messageTs>: {},
 *        ...
 *      }
 *      name: '',
 *      latest: {},
 *      unread_count: 0,
 *      last_read: '0000000000.000000',
 *      max_ts: '0000000000.000000',
 *      members: [],
 *      topic: {},
 *      purpose: {}
 *    },
 *    ...
 * }
 */

function reduce() {
  let state = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
  let action = arguments[1];

  if ((0, _utils.isHandledByMessagesReducer)(action.type)) {
    return (0, _messagesReducer2.default)(state, action);
  }

  let type = action.type;
  let message = action.message;


  switch (type) {
    case _client.RTM_EVENTS.CHANNEL_CREATED:
    case _client.RTM_EVENTS.CHANNEL_JOINED:
    case _client.RTM_EVENTS.CHANNEL_RENAME:
      return (0, _channelHelpers.addOrUpdateChannel)(state, message);
    case _client.RTM_EVENTS.CHANNEL_DELETED:
      return (0, _lodash.omit)(state, message.channel);
    case _client.RTM_EVENTS.CHANNEL_LEFT:
      return (0, _channelHelpers.leaveChannel)(state, message, action.userId);
    case _client.RTM_EVENTS.CHANNEL_ARCHIVE:
      return (0, _channelHelpers.archiveChannel)(state, message, true);
    case _client.RTM_EVENTS.CHANNEL_UNARCHIVE:
      return (0, _channelHelpers.archiveChannel)(state, message, false);
    case _client.RTM_EVENTS.USER_TYPING:
      return (0, _channelHelpers.userIsTyping)(state, message, action.isTyping);
    case _client.RTM_EVENTS.CHANNEL_HISTORY_CHANGED:
    default:
      return state;
  }
}